@@ -6,10 +6,10 @@ resource 'vers' (1,purgeable) {
 	0x01,
 	0x02,
 	release,
-	0x00,
+	0x07,
 	verJapan,
-	"ver.A.02",
-	"GLOBALBASE COSMOS ver.A.02 for Macintosh"
+	"ver.A.02.07",
+	"GLOBALBASE COSMOS ver.A.02.07 for Macintosh"
 };
 
 
