@@ -19,6 +19,7 @@
 
 #include	<stdio.h>
 #include	"xl.h"
+#include	"rcache.h"
 
 int
 _main(int argc,char ** argv)
@@ -41,6 +42,12 @@ extern int view_agent_switch;
 
 		open_control_port();
 		loading_file(0, l_string(std_cm,"local"), 1);
+
+		set_rcache_dir_path(
+			l_string(std_cm,get_preference_path()),
+			l_string(std_cm,"cache"));
+		enable_rcache();
+
 		if ( view_agent_switch == 0 )
 			start_gbview();
 		event_task();
