@@ -85,9 +85,14 @@ int x,y;
 	if ( mx == 0 )
 		return;
 	if ( mx->resolution < 0 )
-		er_panic("check_matrix(1)");
+		er_panic("matrix(1)");
 	if ( mx->loaded_reso < 0 )
 		er_panic("check_matrix(1.1)");
+	if ( check_fnan(mx->resolution) < 0 )
+		er_panic("matrix(20)");
+	if ( check_fnan(mx->loaded_reso) < 0 )
+		er_panic("matrix(21)");
+
 
 	if ( mx->rect[0][0].tl.x != mx->rect[0][1].tl.x )
 		er_panic("check_matrix(2)");
@@ -112,6 +117,15 @@ int x,y;
 
 	for ( x = 0 ; x < 2 ; x ++ )
 		for ( y = 0 ; y < 2 ; y ++ ) {
+			if ( check_fnan(mx->rect[x][y].tl.x) < 0 )
+				er_panic("matrix(22)");
+			if ( check_fnan(mx->rect[x][y].tl.y) < 0 )
+				er_panic("matrix(23)");
+			if ( check_fnan(mx->rect[x][y].br.x) < 0 )
+				er_panic("matrix(24)");
+			if ( check_fnan(mx->rect[x][y].br.y) < 0 )
+				er_panic("matrix(25)");
+
 			if ( mx->mx[x][y] == 0 )
 				continue;
 			if ( mx->mx[x][y]->parent != mx )
@@ -121,7 +135,7 @@ int x,y;
 }
 
 void
-check_matrix()
+_x_check_matrix()
 {
 	if ( rc.matrix == 0 )
 		return;
@@ -130,6 +144,16 @@ check_matrix()
 	_check_matrix(rc.matrix);
 }
 
+void
+check_matrix()
+{
+	lock_task(radar_lock);
+	_x_check_matrix();
+	unlock_task(radar_lock,"check_matrix");
+}
+
+
+
 void
 check_parent(RADAR_MATRIX * mx)
 {
@@ -506,6 +530,8 @@ int
 _rc_task_lock_check(int t)
 {
 int lp;
+
+
 	lp = lock_pattern[t];
 	if ( rc.task_mode&(~lp) )
 		return -1;
@@ -1179,8 +1205,10 @@ GB_POINT org;
 	h = r->br.y - r->tl.y;
 
 	mx->resolution = ((RADAR_DOTS/w + RADAR_DOTS/h)/2)*0.70710678118;
+/*
 if ( check_fnan(mx->resolution) < 0 )
 er_panic("1");
+*/
 	mx->loaded_reso = mx->resolution*2;
 
 	radius = 2*RADAR_DOTS_RATE*w*h/(w+h);
@@ -1197,7 +1225,7 @@ er_panic("1");
 		}
 	mx->list = 0;
 	rc.matrix = mx;
-
+	mx->parent = 0;
 }
 
 void
@@ -1263,8 +1291,10 @@ GB_POINT c;
 	c.y = (r->tl.y + r->br.y)/2;
 	mx = _new_radar_matrix();
 	mx->resolution = 2*reso;
+/*
 if ( check_fnan(mx->resolution) < 0 )
 er_panic("2");
+*/
 	mx->loaded_reso = mx->resolution*2;
 
 
@@ -1348,8 +1378,10 @@ GB_POINT rtl,rbr;
 
 	mx = _new_radar_matrix();
 	mx->resolution = rc.matrix->resolution/2;
+/*
 if ( check_fnan(mx->resolution) < 0 )
 er_panic("3");
+*/
 	mx->loaded_reso = mx->resolution*2;
 
 
@@ -2013,9 +2045,13 @@ int i,j;
 set_cpu_msg(2501);
 
 ss_printf("NEXT %i\n",next);
+
+
 	wfid = wf_get_current();
 	if ( next )
 		wf_set_current_target(next);
+if ( env.flame == 0 )
+er_panic("???");
 
 	switch ( type ) {
 	case RCT_CHANGE:
@@ -2037,15 +2073,21 @@ ss_printf("NEXT %i\n",next);
 	wfid = wf_get_current();
 	draw = wf_get_resource(wfid);
 
+
 	wlock_base_url("remake_cache");
 
 	if ( draw == 0 ) {
 
+
+ss_printf("DRAW ZERO *************************************** DRAW ZERO\n");
+if ( env.flame == 0 )
+er_panic("stop");
 		lock_task(radar_lock);
 		if ( rc.base_url )
 			d_f_ree(rc.base_url);
 		rc.base_url = 0;
 		_free_radar_matrix(rc.matrix);
+		rc.matrix = 0;
 		for ( ; rc.crd[0].next != &rc.crd[0] ; ) {
 			c = rc.crd[0].next;
 			_free_radar_crd(c);
@@ -2058,6 +2100,7 @@ ss_printf("NEXT %i\n",next);
 	new = ll_copy_str(get_url_str2(&draw->h.entry),1521);
 
 
+
 	if ( rc.base_url == 0 ) {
 
 		free_radar_matrix();
@@ -2076,6 +2119,7 @@ ss_printf("NEXT %i\n",next);
 		goto end;
 	get_url2(&u,rc.base_url,1558);
 
+
 	mh = get_mh_from_route(ses,&u,mpr);
 
 
@@ -2093,6 +2137,8 @@ ss_printf("NEXT %i\n",next);
 	}
 
 
+
+
 	free_radar_matrix();
 
 	map_from_flame(mh,rc.ptr,rc.res,RADAR_CACHE_SIZE*8);
@@ -2119,6 +2165,8 @@ ss_printf("ins %s\n",n_string(std_cm,c->obj_path));
 			insert_radar_matrix(c);
 	}
 
+
+
 ss_printf("REMAKE %ls --> ",rc.base_url);
 
 	d_f_ree(rc.base_url);
@@ -2135,6 +2183,7 @@ last:
 	unlock_base_url();
 	{}
 
+
 	return 1;
 }
 
@@ -2284,14 +2333,16 @@ AVT_NODE * reso_tree;
 		for ( n = lst->mx->list ; n ; n = n->matrix_next ) {
 			c = n->crd;
 			c->lock ++;
-/*
+
 ss_printf("CMP BEFOR %ls %lf\n",c->crd_path,(double)c->resolution);
-*/
+
 			if ( cross_rect_rect(&c->minrect,r) == 0 )
 				continue;
 
 			if ( c->resolution > reso )
 				continue;
+			if ( c->crd_r && (c->crd_r->h.flags & RF_INDICATE) == RF_I_OFF )
+				continue;
 
 ss_printf("CMP CACHE %ls %lf\n",c->crd_path,(double)c->resolution);
 /*
@@ -4419,6 +4470,10 @@ _loading_cube(int ses,RADAR_MATRIX * mx,REAL1 min,REAL1 max)
 RADAR_MATRIX * p;
 GB_RECT r;
 
+/*
+if ( rc.matrix && check_fnan(rc.matrix->resolution) < 0 )
+er_panic("fnan(1)");
+*/
 
 	if ( mx->resolution*2 != max )
 		er_panic("loading_cube(1)");
@@ -4479,6 +4534,11 @@ XL_SEXP * u, * v,* p;
 int f;
 REAL1 window,_max,_min;
 
+/*
+if ( rc.matrix && check_fnan(rc.matrix->resolution) < 0 )
+er_panic("fnan(1)");
+*/
+
 
 	lock_task(radar_lock);
 	if ( rc.matrix == 0 ) {
@@ -4510,6 +4570,12 @@ retry_search:
 			reso >= min ; reso = reso / 2 );
 	_max = lst->mx->resolution*2;
 	_min = reso;
+/*
+if ( check_fnan(_max) < 0 )
+er_panic("lm(1)");
+if ( check_fnan(_min) < 0 )
+er_panic("lm(2)");
+*/
 
 
 	for ( lst2 = lst ; lst2 ; lst2 = lst2->next )
@@ -4751,10 +4817,21 @@ set_cpu_msg(3);
 printf("sleep load task %i %x\n",get_tid(),rc.base_url);
 */
 		_rc_task_unlock(TM_LOAD);
+
+/*
+if ( rc.matrix && check_fnan(rc.matrix->resolution) < 0 )
+er_panic("fnan(1)");
+*/
+
 		sleep_task((int)loading_task,radar_lock);
 /*
 printf("wakeup load task %x\n",rc.base_url);
 */
+/*
+if ( rc.matrix && check_fnan(rc.matrix->resolution) < 0 )
+er_panic("fnan(1)");
+*/
+
 set_cpu_msg(4);
 		lock_task(radar_lock);
 		continue;
@@ -4765,18 +4842,39 @@ set_cpu_msg(5);
 
 	loading_loop:
 set_cpu_msg(1110);
+/*
+if ( rc.matrix && check_fnan(rc.matrix->resolution) < 0 )
+er_panic("fnan(1)");
+*/
+
 		set_l_mode();
 		rc_task_lock(TM_LOAD);
 		if ( rc.remake_req )
 			goto next;
+/*
+if ( rc.matrix && check_fnan(rc.matrix->resolution) < 0 )
+er_panic("fnan(1)");
+*/
+
+
 		if ( loading_matrix(&r,&reso_window,&reso_max,ses)
 				< 0 ) {
 
 			rc_task_unlock(TM_LOAD);
 			reset_l_mode();
+/*
+if ( rc.matrix && check_fnan(rc.matrix->resolution) < 0 )
+er_panic("fnan(1)");
+*/
+
 			goto loading_loop;
 		}
 	next:
+/*
+if ( rc.matrix && check_fnan(rc.matrix->resolution) < 0 )
+er_panic("fnan(1)");
+*/
+
 
 		rc_task_unlock(TM_LOAD);
 		reset_l_mode();
