@@ -93,6 +93,14 @@ init_gb_MPRouting(XLISP_ENV * env)
 }
 
 
+void
+insert_queue_mp_t(SYS_QUEUE * q,MP_T *n,int wflag)
+{
+	insert_queue(q,n,wflag);
+	if ( q->total_cnt > 6000 )
+		er_panic("insert_queue_mp_t");
+}
+
 void
 gc_mp_t(MP_T * n)
 {
@@ -158,35 +166,45 @@ int i,j,k,sub;
 	if ( pos < 0 )
 		start = n->start;
 	else	start = n->mp_tbl[pos].crd;
+set_cpu_msg(720024);
 	mpi = get_mpi(0,start,MPI_READ);
+set_cpu_msg(720025);
 	if ( mpi == 0 )
 		return;
+set_cpu_msg(720026);
 	a = get_mpi_around(mpi);
+set_cpu_msg(720027);
 	if ( a == 0 )
 		return;
 	flush_mpi(mpi);
+set_cpu_msg(720028);
 	for ( i = n->mp_ptr-1 ; i > pos+1 ; i -- ) {
 		result = cmp_around(n->mp_tbl[i].crd,a);
 		if ( result )
 			goto mutch;
 	}
+set_cpu_msg(720029);
 	free_around_list(a);
 	return;
 mutch:
 
+set_cpu_msg(720030);
+
 	sub = i - pos - 1;
 	*local_ptr -= sub;
 	for ( j = pos+1 ; j < i ; j ++ )
 		free_mp_entry(&n->mp_tbl[j]);
 	for ( j = pos+1 ; i < n->mp_ptr ; j ++ , i ++ )
 		n->mp_tbl[j] = n->mp_tbl[i];
-	for ( k = j ; k < n->mp_ptr ; k ++ )
+	for ( k = n->mp_ptr - sub ; k < n->mp_ptr ; k ++ )
 		reset_mp_entry(&n->mp_tbl[k]);
 	if ( check_map_ptr(&n->mp_tbl[pos+1]) )
 		d_f_ree(n->mp_tbl[pos+1].map);
+set_cpu_msg(720031);
 	n->mp_tbl[pos+1].map = ll_copy_str(result->map,346);
 	n->mp_ptr = j;
 	free_around_list(a);
+set_cpu_msg(720032);
 
 }
 
@@ -353,11 +371,11 @@ int local_ip,p;
 				n->ret_sts = MPE_NO_ROUTE;
 				routing_result(n);
 			}
-			else 	insert_queue(&rque2,n,1);
+			else 	insert_queue_mp_t(&rque2,n,1);
 		}
 		else {
 			n->remote = load_meta_routing(ses,"meta",n->target);
-			insert_queue(&rque1r,n,1);
+			insert_queue_mp_t(&rque1r,n,1);
 		}
 		free_url(&u);
 
@@ -426,7 +444,7 @@ XL_SEXP * cid;
 		if ( n->target_cid == 0 )
 			goto err;
 
-		insert_queue(&rque2,n,1);
+		insert_queue_mp_t(&rque2,n,1);
 
 		gc_pop(0,0);
 		continue;
@@ -503,7 +521,7 @@ URL u;
 			else	get_url2(&u,n->mp_tbl[n->mp_ptr-1].crd,346);
 			n->h.key = get_server_key(&u);
 			free_url(&u);
-			insert_queue(&rque3,n,1);
+			insert_queue_mp_t(&rque3,n,1);
 			break;
 		default:
 			routing_result(n);
@@ -609,15 +627,18 @@ XL_SEXP * t;
 	}
 	else {
 		for ( mp_ptr = 0 ; mp_ptr < ttl ; mp_ptr ++ ) {
+set_cpu_msg(720020);
 			reset_mp_entry(&mp[mp_ptr]);
 			if ( get_type(s) != XLT_PAIR )
 				break;
+set_cpu_msg(720021);
 			t = car(s);
 			if ( get_type(t) != XLT_STRING )
 				return MPE_UNKNOWN;
 			mp[mp_ptr].map = ll_copy_str(t->string.data,1380);
 			s = cdr(s);
 			t = car(s);
+set_cpu_msg(720022);
 			if ( get_type(t) != XLT_STRING ) {
 				d_f_ree(mp[mp_ptr].map);
 				mp[mp_ptr].map = 0;
@@ -625,6 +646,7 @@ XL_SEXP * t;
 			}
 			mp[mp_ptr].crd = ll_copy_str(t->string.data,1379);
 			s= cdr(s);
+set_cpu_msg(720023);
 		}
 		return mp_ptr;
 	}
@@ -685,7 +707,7 @@ set_cpu_msg(720013);
 				n->ret_mode,
 				n->option);
 
-		insert_queue(&rque4,n,1);
+		insert_queue_mp_t(&rque4,n,1);
 
 		gc_pop(0,0);
 	}
@@ -743,10 +765,12 @@ int mp_ptr;
 
 		gc_push(0,0,"routing_task");
 
+set_cpu_msg(720041);
 		if ( check_queue(que,sq_key_cond,key) == 0 ) {
 			gc_pop(0,0);
 			break;
 		}
+set_cpu_msg(720040);
 		n = delete_queue(que,rq_task4_cond,key,1);
 
 set_cpu_msg(720013);
@@ -755,20 +779,25 @@ set_cpu_msg(720013);
 			&n->mp_tbl[n->mp_ptr],
 			n->ttl - n->mp_ptr,
 			n);
-printf("ret = %i\n",ret);
+set_cpu_msg(720014);
 		if ( ret >= 0 ) {
 			mp_ptr = n->mp_ptr;
 			n->mp_ptr += ret;
 			n->ret_sts = MPE_FIT;
+set_cpu_msg(720015);
 			routing_optimize(n,mp_ptr);
+set_cpu_msg(720016);
 		}
 		else {
 			n->ret_sts = ret;
 		}
+set_cpu_msg(720017);
 		routing_result(n);
+set_cpu_msg(720018);
 
 		gc_pop(0,0);
 	}
+set_cpu_msg(720019);
 
 	release_qkey(que,key);
 	d_f_ree(key);
@@ -801,7 +830,6 @@ URL u;
 	for ( ; rque_init_flag == 0 ; )
 		sleep_sec(1);
 
-printf("QUE MP:MPRouting\n");
 
 set_cpu_msg(720000);
 
@@ -870,12 +898,13 @@ set_cpu_msg(721001);
 set_cpu_msg(721002);
 		switch ( get_type(target) ) {
 		case XLT_STRING:
+set_cpu_msg(721102);
 			ret_sexp = new_d_sexp(&n->d);
 			n->target = ll_copy_str(target->string.data,346);
 			get_url2(&u,target->string.data,365);
 			n->h.key = get_server_key(&u);
 			free_url(&u);
-			insert_queue(&rque1,n,1);
+			insert_queue_mp_t(&rque1,n,1);
 			break;
 		case XLT_PAIR:
 set_cpu_msg(721003);
@@ -886,7 +915,7 @@ set_cpu_msg(721003);
 			}
 			ret_sexp = new_d_sexp(&n->d);
 			n->h.key = nl_copy_str(std_cm,"*");
-			insert_queue(&rque2,n,1);
+			insert_queue_mp_t(&rque2,n,1);
 			break;
 		default:
 set_cpu_msg(721004);
