@@ -21,6 +21,7 @@
 #include	"pdb.h"
 #include	"filespace.h"
 #include	"favt.h"
+#include	"utils.h"
 
 
 
@@ -209,7 +210,7 @@ int type,size,len;
 	w.parent = parent;
 	h = d_alloc(sizeof(*h),12);
 	lseek(p->fid,fofs,SEEK_SET);
-	er = read(p->fid,h,sizeof(*h));
+	er = u_read(p->fid,h,sizeof(*h));
 	if ( er < sizeof(*h) ) {
 		d_f_ree(h);
 		return 0;
@@ -279,7 +280,7 @@ PDB * p;
 	n->h.type = PNT_FAVT_NODE;
 	size = n->h.size = nn->data_len + sizeof(PN_FAVT_NODE);
 	change_endian_favt_node(n);
-	lseek(p->fid,h->fofs,SEEK_SET);
+	u_lseek(p->fid,h->fofs,SEEK_SET);
 	fa_write(p->fid,n,size);
 	d_f_ree(n);
 	return 0;
@@ -297,7 +298,7 @@ PN_FAVT_ROOT r;
 	r.h.type = PNT_FAVT_ROOT;
 	r.h.size = sizeof(r);
 	change_endian_favt_root(&r);
-	lseek(h->p->fid,h->fofs,SEEK_SET);
+	u_lseek(h->p->fid,h->fofs,SEEK_SET);
 	fa_write(h->p->fid,&r,sizeof(r));
 	return 0;
 }
