@@ -21,24 +21,26 @@
 #include	<sys/stat.h>
 #include	"memory_debug.h"
 #include	"utils.h"
-
+#include	"machine/include.h"
 
 int
 u_mkdir(char * str,int mode)
 {
-char * s;
+char * s, * _s;
 int p;
 int ret;
 	p = strlen(str)-1;
 	if ( p <= 0 )
 		return -1;
-	if ( str[p] == '/' ) {
-		s = copy_str(str);
+	s = copy_str(str);
+	if ( s[p] == '/' ) {
 		s[p] = 0;
-		ret = mkdir(s,mode);
-		d_f_ree(s);
-		return ret;
 	}
-	else 	return mkdir(str,mode);
+	_s = change_delim_str(s);
+	ret = m_mkdir(_s,mode);
+	if ( _s != s )
+		d_f_ree(_s);
+	d_f_ree(s);
+	return ret;
 }
 
