@@ -1435,6 +1435,10 @@ commands(char ** argv,FILE * fd)
 		cmd_set(argv);
 	else if ( strcmp(argv[0],"keep") == 0 )
 		cmd_keep(argv);
+	else if ( strcmp(argv[0],"stop") == 0 ) {
+		fprintf(stderr,"stopped.\n");
+		exit(0);
+	}
 	else {
 		fprintf(stderr,"invalid command \"%s\"\n",
 			argv[0]);
@@ -1442,6 +1446,31 @@ commands(char ** argv,FILE * fd)
 	}
 }
 
+set_uname()
+{
+int p[2];
+int id;
+char buf[100];
+int er;
+	pipe(p);
+	id = fork();
+	if ( id == 0 ) {
+		close(1);
+		dup(p[1]);
+		close(p[0]);
+		system("uname");
+		exit(0);
+	}
+	close(p[1]);
+	er = read(p[0],buf,100);
+	close(p[0]);
+	if ( er < 0 )
+		return -1;
+	buf[er-1] = 0;
+	push_stack("UNAME",buf);
+	printf("uname : %s\n",buf);
+}
+
 scan_file()
 {
 FILE * fd;
@@ -1455,6 +1484,7 @@ char * ret_buf;
 		perror("");
 		exit(1);
 	}
+	set_uname();
 start:
 	make_active = 0;
 	for ( ; ; ) {
